fnss.topologies.topology.DirectedTopology.out_degree — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.DirectedTopology.out_degree

`DirectedTopology.` `out_degree`(nbunch=None, weight=None)

  Return the out-degree of a node or nodes.

  The node out-degree is the number of edges pointing out of the node.

  Parameters : | nbunch : iterable container, optional (default=all nodes) A container of nodes. The container will be iterated through once. weight : string or None, optional (default=None) The edge attribute that holds the numerical value used as a weight. If None, then each edge has weight 1. The degree is the sum of the edge weights adjacent to the node.
  Returns : | nd : dictionary, or number A dictionary with nodes as keys and out-degree as values or a number if a single node is specified.

  Examples

      >>> G = nx.DiGraph()   # or MultiDiGraph
      >>> G.add_path([0,1,2,3])
      >>> G.out_degree(0)
      1
      >>> G.out_degree([0,1])
      {0: 1, 1: 1}
      >>> list(G.out_degree([0,1]).values())
      [1, 1]

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »